/**
Author:  Luis Gerardo de la Fraga
Scubes is a program to visualize vox-solids
Copyright (C) 2001 Luis Gerardo de la Fraga

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Author's e-mail: fraga@cs.cinvestav.mx
Address: 
Seccin de Computacin. Dpto. de Ingeniera Elctrica
CINVESTAV-IPN                       
Av. Instituto Politcnico Nacional No. 2508
07300 Mxico, D.F. 
Mxico
**/

#include <qapplication.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qfont.h>
#include <qlayout.h>
#include <qstring.h>
#include <qcombobox.h>
#include <qlistbox.h>
#include <qhbox.h>
#include <qpen.h>
#include <qnamespace.h>
#include <qslider.h>


#include "painter.h"
#include "quadric.h"


Painter::Painter( const char *filename, QWidget *parent, const char *name )
        : QWidget( parent, name )
{
    setMinimumSize( 500, 355 );

    quit = new QPushButton( "Quit", this, "quit" );
    quit->setFont( QFont( "Times", 14, QFont::Bold ) );
    connect( quit, SIGNAL(clicked()), qApp, SLOT(quit()) );

    quadric = new Quadric( filename, this, "quadric" );

    compR = new QSpinBox( 0, 255, 1,  this, "R" ); 
	compR -> setWrapping( TRUE );
	compR -> setValue( 250 );
	connect( compR, SIGNAL(valueChanged(int)), quadric, SLOT(PutRValue(int)) );

    compG = new QSpinBox( 0, 255, 1,  this, "G" ); 
	compG -> setWrapping( TRUE );
	compG -> setValue( 250 );
	connect( compG, SIGNAL(valueChanged(int)), quadric, SLOT(PutGValue(int)) );

    compB = new QSpinBox( 0, 255, 1,  this, "B" ); 
	compB -> setWrapping( TRUE );
	compB -> setValue( 250 );
	connect( compB, SIGNAL(valueChanged(int)), quadric, SLOT(PutBValue(int)) );
	
	whohavelight = new QComboBox( this, "whohavelight" );
	whohavelight -> insertItem( "To Viewer" ); 
	whohavelight -> insertItem( "To Object" ); 
	connect(whohavelight,SIGNAL(activated(int)),quadric,SLOT(LightsTo(int)) );

    QGridLayout *grid = new QGridLayout( this, 2, 2, 5 ); //2x2, 5 pixel border
    grid->addWidget( quadric, 0, 1 );
    grid->setColStretch( 1, 10 );

	QVBoxLayout *leftBox = new QVBoxLayout;
	grid->addLayout( leftBox, 0, 0 );
	leftBox->addWidget( quit );
	leftBox->addWidget( compR );
	leftBox->addWidget( compG );
	leftBox->addWidget( compB );
	leftBox->addWidget( whohavelight );

	light_dis = new QSlider( 1,100,1,1, QSlider::Horizontal, this, "slider" );
    connect(light_dis, SIGNAL(valueChanged( int)),quadric,SLOT(dist_slider(int)) );

	QLabel * dist_label = new QLabel( this, "Dist_label" );
    connect(light_dis,SIGNAL(valueChanged(int)),dist_label,SLOT(setNum(int)) );

	QBoxLayout * hvals2 = new QHBoxLayout(  5, "HLayout2"  );
    grid->addLayout( hvals2, 1, 1 );
	hvals2->addWidget( light_dis );
	hvals2->addWidget( dist_label );

}

